==> react-molecule-data-counter-1.5.0.tgz: package/lib/index.js <==
import { jsxs as _jsxs } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
import { useState } from 'react';
import cx from 'classnames';
import AtomButton from '@s-ui/react-atom-button';
import AtomInput, { inputSizes } from '@s-ui/react-atom-input';
import MoleculeField from '@s-ui/react-molecule-field';
var BUTTON_TYPE = 'secondary';
var BASE_CLASS = "sui-MoleculeDataCounter";
var CLASS_INPUT_CONTAINER = BASE_CLASS + "-container";

var MoleculeDataCounter = function MoleculeDataCounter(_ref) {
  var id = _ref.id,
      label = _ref.label,
      value = _ref.value,
      errorTextProps = _ref.errorText,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? inputSizes.MEDIUM : _ref$size,
      _ref$charsSize = _ref.charsSize,
      charsSize = _ref$charsSize === void 0 ? 2 : _ref$charsSize,
      _ref$max = _ref.max,
      max = _ref$max === void 0 ? 99 : _ref$max,
      _ref$min = _ref.min,
      min = _ref$min === void 0 ? 1 : _ref$min,
      minValueHelpText = _ref.minValueHelpText,
      minValueErrorText = _ref.minValueErrorText,
      maxValueHelpText = _ref.maxValueHelpText,
      maxValueErrorText = _ref.maxValueErrorText,
      onChange = _ref.onChange,
      disabled = _ref.disabled;
  if (value) value = String(value);else if (min) value = String(min);else value = '0';

  var _useState = useState(value),
      internalValue = _useState[0],
      setInternalValue = _useState[1];

  var numInternalValue = Number(internalValue);
  var numMax = Number(max);
  var numMin = Number(min);
  var isBelowMaxValue = numInternalValue < numMax;
  var isOverMinValue = numInternalValue > numMin;
  var isMaxValue = numInternalValue === numMax;
  var isMinValue = numInternalValue === numMin;
  var isLowerThanMinValue = numInternalValue < numMin;
  var isHigherThanMaxValue = numInternalValue > numMax;
  var decrementDisabled = disabled || numInternalValue <= numMin;
  var incrementDisabled = disabled || numInternalValue >= numMax;

  var assignValue = function assignValue(e, _ref2) {
    var nValue = _ref2.nValue;
    var value = String(nValue);
    setInternalValue(value);
    onChange(e, {
      value: value
    });
  };

  var incrementValue = function incrementValue(e) {
    if (isBelowMaxValue) {
      var nValue = internalValue === '' ? min : parseInt(internalValue) + 1;
      assignValue(e, {
        nValue: nValue
      });
    }
  };

  var decrementValue = function decrementValue(e) {
    if (isOverMinValue) {
      var nValue = internalValue === '' ? min : parseInt(internalValue) - 1;
      assignValue(e, {
        nValue: nValue
      });
    }
  };

  var handleChange = function handleChange(e, _ref3) {
    var value = _ref3.value;
    var nValue = parseInt(value, 10);

    if (value.length <= 2 && !isNaN(nValue)) {
      assignValue(e, {
        nValue: nValue
      });
    }
  };

  var handleKeyDown = function handleKeyDown(e, _ref4) {
    var value = _ref4.value;
    var key = e.key;
    if (key === 'ArrowUp') incrementValue(e);
    if (key === 'ArrowDown') decrementValue(e);
  };

  var helpText, errorText;

  if (!disabled) {
    if (isMaxValue) helpText = maxValueHelpText;else if (isMinValue) helpText = minValueHelpText;else helpText = null;
    if (isLowerThanMinValue) errorText = minValueErrorText;else if (isHigherThanMaxValue) errorText = maxValueErrorText;else if (errorTextProps) errorText = errorTextProps;else errorText = null;
  }

  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS,
    children: /*#__PURE__*/_jsx(MoleculeField, {
      name: id,
      label: label,
      helpText: helpText,
      errorText: errorText,
      children: /*#__PURE__*/_jsxs("div", {
        className: cx(CLASS_INPUT_CONTAINER, CLASS_INPUT_CONTAINER + "--" + size),
        children: [/*#__PURE__*/_jsx(AtomButton, {
          disabled: decrementDisabled,
          onClick: decrementValue,
          type: BUTTON_TYPE,
          children: "-"
        }), /*#__PURE__*/_jsx(AtomInput, {
          id: id,
          disabled: disabled,
          size: size,
          charsSize: charsSize,
          value: internalValue,
          onKeyDown: handleKeyDown,
          onChange: handleChange
        }), /*#__PURE__*/_jsx(AtomButton, {
          disabled: incrementDisabled,
          onClick: incrementValue,
          type: BUTTON_TYPE,
          children: "+"
        })]
      })
    })
  });
};

MoleculeDataCounter.displayName = 'MoleculeDataCounter';
export default MoleculeDataCounter;
export { inputSizes as moleculeDataCounterSizes };

==> react-molecule-data-counter-1.6.0.tgz: package/lib/index.js <==
import { jsxs as _jsxs } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
import { useState } from 'react';
import cx from 'classnames';
import AtomButton, { atomButtonSizes } from '@s-ui/react-atom-button';
import AtomInput, { inputSizes } from '@s-ui/react-atom-input';
import MoleculeField from '@s-ui/react-molecule-field';
import { ACTIONS } from './config';
var BUTTON_TYPE = 'secondary';
var BASE_CLASS = "sui-MoleculeDataCounter";
var CLASS_INPUT_CONTAINER = BASE_CLASS + "-container";

var MoleculeDataCounter = function MoleculeDataCounter(_ref) {
  var AddIcon = _ref.addIcon,
      _ref$charsSize = _ref.charsSize,
      charsSize = _ref$charsSize === void 0 ? 2 : _ref$charsSize,
      disabled = _ref.disabled,
      errorTextProps = _ref.errorText,
      id = _ref.id,
      _ref$inputDisabled = _ref.inputDisabled,
      inputDisabled = _ref$inputDisabled === void 0 ? false : _ref$inputDisabled,
      _ref$isLoading = _ref.isLoading,
      isLoading = _ref$isLoading === void 0 ? false : _ref$isLoading,
      label = _ref.label,
      _ref$max = _ref.max,
      max = _ref$max === void 0 ? 99 : _ref$max,
      maxValueErrorText = _ref.maxValueErrorText,
      maxValueHelpText = _ref.maxValueHelpText,
      _ref$min = _ref.min,
      min = _ref$min === void 0 ? 1 : _ref$min,
      minValueErrorText = _ref.minValueErrorText,
      minValueHelpText = _ref.minValueHelpText,
      onChange = _ref.onChange,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? inputSizes.MEDIUM : _ref$size,
      SubstractIcon = _ref.substractIcon,
      value = _ref.value;
  if (value) value = String(value);else if (min) value = String(min);else value = '0';

  var _useState = useState(value),
      internalValue = _useState[0],
      setInternalValue = _useState[1];

  var _useState2 = useState(),
      lastAction = _useState2[0],
      setLastActions = _useState2[1];

  var numInternalValue = Number(internalValue);
  var numMax = Number(max);
  var numMin = Number(min);
  var isBelowMaxValue = numInternalValue < numMax;
  var isOverMinValue = numInternalValue > numMin;
  var isMaxValue = numInternalValue === numMax;
  var isMinValue = numInternalValue === numMin;
  var isLowerThanMinValue = numInternalValue < numMin;
  var isHigherThanMaxValue = numInternalValue > numMax;
  var decrementDisabled = disabled || numInternalValue <= numMin;
  var incrementDisabled = disabled || numInternalValue >= numMax;

  var assignValue = function assignValue(e, _ref2) {
    var nValue = _ref2.nValue;
    var value = String(nValue);
    setInternalValue(value);
    onChange(e, {
      value: value
    });
  };

  var incrementValue = function incrementValue(e) {
    setLastActions(ACTIONS.MORE);

    if (isBelowMaxValue) {
      var nValue = internalValue === '' ? min : parseInt(internalValue) + 1;
      assignValue(e, {
        nValue: nValue
      });
    }
  };

  var decrementValue = function decrementValue(e) {
    setLastActions(ACTIONS.LESS);

    if (isOverMinValue) {
      var nValue = internalValue === '' ? min : parseInt(internalValue) - 1;
      assignValue(e, {
        nValue: nValue
      });
    }
  };

  var handleChange = function handleChange(e, _ref3) {
    var value = _ref3.value;
    setLastActions(ACTIONS.CHANGE);
    var nValue = parseInt(value, 10);

    if (value.length <= 2 && !isNaN(nValue)) {
      assignValue(e, {
        nValue: nValue
      });
    }
  };

  var handleKeyDown = function handleKeyDown(e, _ref4) {
    var value = _ref4.value;
    var key = e.key;
    if (key === 'ArrowUp') incrementValue(e);
    if (key === 'ArrowDown') decrementValue(e);
  };

  var helpText, errorText;

  if (!disabled) {
    if (isMaxValue) helpText = maxValueHelpText;else if (isMinValue) helpText = minValueHelpText;else helpText = null;
    if (isLowerThanMinValue) errorText = minValueErrorText;else if (isHigherThanMaxValue) errorText = maxValueErrorText;else if (errorTextProps) errorText = errorTextProps;else errorText = null;
  }

  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS,
    children: /*#__PURE__*/_jsx(MoleculeField, {
      name: id,
      label: label,
      helpText: helpText,
      errorText: errorText,
      children: /*#__PURE__*/_jsxs("div", {
        className: cx(CLASS_INPUT_CONTAINER, CLASS_INPUT_CONTAINER + "--" + size),
        children: [/*#__PURE__*/_jsx(AtomButton, {
          disabled: decrementDisabled,
          isLoading: isLoading && lastAction === ACTIONS.LESS,
          onClick: decrementValue,
          size: size === inputSizes.SMALL ? atomButtonSizes.SMALL : null,
          type: BUTTON_TYPE,
          children: SubstractIcon ? /*#__PURE__*/_jsx(SubstractIcon, {}) : '-'
        }), /*#__PURE__*/_jsx(AtomInput, {
          charsSize: charsSize,
          disabled: disabled || inputDisabled,
          id: id,
          isLoading: isLoading && lastAction === ACTIONS.CHANGE,
          onChange: handleChange,
          onKeyDown: handleKeyDown,
          size: size,
          value: internalValue
        }), /*#__PURE__*/_jsx(AtomButton, {
          disabled: incrementDisabled,
          isLoading: isLoading && lastAction === ACTIONS.MORE,
          onClick: incrementValue,
          size: size === inputSizes.SMALL ? atomButtonSizes.SMALL : null,
          type: BUTTON_TYPE,
          children: AddIcon ? /*#__PURE__*/_jsx(AddIcon, {}) : '+'
        })]
      })
    })
  });
};

MoleculeDataCounter.displayName = 'MoleculeDataCounter';
export default MoleculeDataCounter;
export { inputSizes as moleculeDataCounterSizes };
